/* 
  tiltmap.js

  Written by John Keogh of EyesBot, LLC for demo purposes and released 
  into the public domain.  No warrantee or guarantee of any type is 
  associated with this code.  Use at you own risk.  
  
  None of this code handles errors well, as it is coded for clarity 
  rather than completeness.
*/

var http = require('http');
var helenus = require('helenus');
var express = require('express');
var url = require("url");

var app = express();

//need to set up and connect (next code block) the connection pool 
//for Helenus prior to using it
var pool =  new helenus.ConnectionPool({
	hosts:['localhost:9160'],
	keyspace:'tiltmap',
	cqlversion:'3.0.0'
});

pool.connect(function(err, keyspace){
    if(err){
    	throw(err);
    } else {
    	
    }
});

//gets a list of all runs from run table
app.get('/runs', function(req, res) {
	  pool.cql('select run_name from run', function(err, results){
		  if(err){
			  console.log(err);
		  }
		  res.write("{\"runnames\": [\r\n");
		  var firstRun = true;
		  results.forEach(function(row){
			  //each row
			  if(!firstRun){
				  res.write(",\r\n");
			  }
			  else{
				  firstRun = false;
			  }
			  res.write("{");
			  var firstData = true;
			  row.forEach(function(name,value,ts,ttl){
				  if(!firstData){
					  firstData = false;
					  res.write(", ");
				  }
				  //each column, only one in this case, but I like the code
				  res.write("\""+name.toString( )+"\""+":"+"\""+value.toString( )+"\"");
			  });
			  res.write("}");
		  });
		  res.write("]}\r\n");
		  res.end();
	  });
});

//add a new tilt measurement.  All of the tilt measurements are keyed by a run and the x and y location of 
//the measurement
///addtiltmeasurement?runname=[run name]&xlocation=[some float]&ylocation=[some float]&xtilt=[some float]&ytilt=[some float]&ztilt=[some float]
app.get('/addtiltmeasurement', function(req, res) {
	if(req.query.runname&&req.query.xlocation&&req.query.ylocation
			&&req.query.xtilt&&req.query.ytilt&&req.query.ztilt){
		pool.cql('insert into tiltmeasurement ( run_name, x_location,  y_location, x_tilt, y_tilt, z_tilt) values ( \''+req.query.runname+'\', '+req.query.xlocation+', '+
				req.query.ylocation+', '+req.query.xtilt+', '+req.query.ytilt+', '+req.query.ztilt+' )', function(err, results){
			  if(err){
					res.send("error");
			  }
			  else{
					res.send("success");
			  }
	    });
	}
});

//add a new run to the run table
///addrun?runname=[run name]
app.get('/addrun', function(req, res) {
	if(req.query.runname){
		pool.cql('insert into run (run_name) values (\''+req.query.runname+'\')', function(err, results){
			  if(err){
					res.send("error");
			  }
			  else{
					res.send("success");
			  }
	    });
	}
});

//retrieve information for a single run, format of path and query for URL is
//run?id=[run name]
app.get('/run/:id', function(req, res) {
	pool.cql('select run_name, x_location,  y_location, x_tilt, y_tilt, z_tilt from tiltmeasurement where run_name = \''+req.query.id+'\'', function(err, results){
		  res.write("{\"runs\": [\r\n");
		  var firstRun = true;
		  results.forEach(function(row){
			  //each row
			  if(firstRun){
				  firstRun = false;
			  }
			  else{
				  res.write(", ");
			  }
			  res.write("{\r\n");
			  var firstData = true;
			  row.forEach(function(name,value,ts,ttl){
				  if(firstData){
					  firstData = false;
				  }
				  else{
					  res.write(", ");
				  }
				  //each column, only one in this case, but I like the code
				  res.write("\""+name.toString()+"\": \""+value.toString()+"\"\r\n");
			  });
			  res.write("}\r\n");
		  });
		  res.write("]}\r\n");
		  res.end();
	});
});
 
//This is for static content.  Put it under public, and public is the html root
//directory.  
app.use(express.logger('dev'));
app.use(express.static(__dirname + '/public'));
app.use(app.router);

app.listen(3000);
console.log('Listening on port 3000...');

